==> jc-1.4.0.tar.gz: java/awt/event/FocusEvent.h <==
// public class java.awt.event.FocusEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class 69e67f1e98271f08 java_awt_event_FocusEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_event_ComponentEvent

#include "java/awt/event/ComponentEvent.h"

#ifndef _JC_java_awt_event_FocusEvent_H_
#define _JC_java_awt_event_FocusEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_FocusEvent$sub_refs	_jc_java_awt_event_FocusEvent$sub_refs;
typedef struct _jc_java_awt_event_FocusEvent$sub_nonrefs	_jc_java_awt_event_FocusEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_FocusEvent$refs	_jc_java_awt_event_FocusEvent$refs;
typedef struct _jc_java_awt_event_FocusEvent$nonrefs	_jc_java_awt_event_FocusEvent$nonrefs;
typedef struct _jc_java_awt_event_FocusEvent$object	_jc_java_awt_event_FocusEvent$object;

typedef struct _jc_java_awt_event_FocusEvent$fields_struct	_jc_java_awt_event_FocusEvent$fields_struct;
typedef const struct _jc_java_awt_event_FocusEvent$vmethods	_jc_java_awt_event_FocusEvent$vmethods;
typedef const struct _jc_java_awt_event_FocusEvent$vtable	_jc_java_awt_event_FocusEvent$vtable;
typedef const struct _jc_java_awt_event_FocusEvent$vtype	_jc_java_awt_event_FocusEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_FocusEvent$fields_struct {
	jlong	serialVersionUID;
	jint	FOCUS__5fFIRST;
	jint	FOCUS__5fGAINED;
	jint	FOCUS__5fLAST;
	jint	FOCUS__5fLOST;
};
extern _jc_java_awt_event_FocusEvent$fields_struct _jc_java_awt_event_FocusEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_FocusEvent$method$_init$97af01f308697cf5(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *, struct _jc_java_awt_Component$object *, jint);
extern void _jc_java_awt_event_FocusEvent$method$_init$cb15de6f21159dac(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *, struct _jc_java_awt_Component$object *, jint, jboolean);
extern void _jc_java_awt_event_FocusEvent$method$_init$a2d9d864cd7df0c6(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *, struct _jc_java_awt_Component$object *, jint, jboolean, struct _jc_java_awt_Component$object *);

// Virtual methods
extern struct _jc_java_awt_Component$object *_jc_java_awt_event_FocusEvent$method$getOppositeComponent$dcea3e9ac80c85de(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *);
extern jboolean _jc_java_awt_event_FocusEvent$method$isTemporary$496c52edea5a99b7(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_event_FocusEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_FocusEvent$method_info$getOppositeComponent$dcea3e9ac80c85de;
extern _jc_method _jc_java_awt_event_FocusEvent$method_info$isTemporary$496c52edea5a99b7;
extern _jc_method _jc_java_awt_event_FocusEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_FocusEvent$vmethods {
	struct _jc_java_awt_Component$object	*(*getOppositeComponent$dcea3e9ac80c85de)(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *);
	jboolean	(*isTemporary$496c52edea5a99b7)(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *);
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *);
};

// Vtable
struct _jc_java_awt_event_FocusEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_FocusEvent$vmethods	java_awt_event_FocusEvent;
};

// Vtype
struct _jc_java_awt_event_FocusEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_FocusEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_FocusEvent$sub_refs {
	struct _jc_java_awt_Component$object	*opposite;
};

// Reference instance fields (object)
struct _jc_java_awt_event_FocusEvent$refs {
    _jc_java_awt_event_FocusEvent$sub_refs	java_awt_event_FocusEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_FocusEvent$sub_nonrefs {
	jboolean	temporary;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_FocusEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_FocusEvent$sub_nonrefs	java_awt_event_FocusEvent;
};

// Object instance structure
struct _jc_java_awt_event_FocusEvent$object {
	_jc_java_awt_event_FocusEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_FocusEvent$vtype	*vtype;
	_jc_java_awt_event_FocusEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_FocusEvent$vtype _jc_java_awt_event_FocusEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_FocusEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_FocusEvent$class_object;

#endif	/* _JC_java_awt_event_FocusEvent_H_ */

==> jc-1.4.5.tar.gz: java/awt/event/FocusEvent.h <==
// public class java.awt.event.FocusEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class 69e67f1e98271f08 java_awt_event_FocusEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_event_ComponentEvent

#include "java/awt/event/ComponentEvent.h"

#ifndef _JC_java_awt_event_FocusEvent_H_
#define _JC_java_awt_event_FocusEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_FocusEvent$sub_refs	_jc_java_awt_event_FocusEvent$sub_refs;
typedef struct _jc_java_awt_event_FocusEvent$sub_nonrefs	_jc_java_awt_event_FocusEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_FocusEvent$refs	_jc_java_awt_event_FocusEvent$refs;
typedef struct _jc_java_awt_event_FocusEvent$nonrefs	_jc_java_awt_event_FocusEvent$nonrefs;
typedef struct _jc_java_awt_event_FocusEvent$object	_jc_java_awt_event_FocusEvent$object;

typedef struct _jc_java_awt_event_FocusEvent$fields_struct	_jc_java_awt_event_FocusEvent$fields_struct;
typedef const struct _jc_java_awt_event_FocusEvent$vmethods	_jc_java_awt_event_FocusEvent$vmethods;
typedef const struct _jc_java_awt_event_FocusEvent$vtable	_jc_java_awt_event_FocusEvent$vtable;
typedef const struct _jc_java_awt_event_FocusEvent$vtype	_jc_java_awt_event_FocusEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_FocusEvent$fields_struct {
	jlong	serialVersionUID;
	jint	FOCUS__5fFIRST;
	jint	FOCUS__5fGAINED;
	jint	FOCUS__5fLAST;
	jint	FOCUS__5fLOST;
};
extern _jc_java_awt_event_FocusEvent$fields_struct _jc_java_awt_event_FocusEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_FocusEvent$method$_init$97af01f308697cf5(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *, struct _jc_java_awt_Component$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_FocusEvent$method$_init$cb15de6f21159dac(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *, struct _jc_java_awt_Component$object *, jint, jboolean) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_FocusEvent$method$_init$a2d9d864cd7df0c6(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *, struct _jc_java_awt_Component$object *, jint, jboolean, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Component$object *_jc_java_awt_event_FocusEvent$method$getOppositeComponent$dcea3e9ac80c85de(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_event_FocusEvent$method$isTemporary$496c52edea5a99b7(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_event_FocusEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_FocusEvent$method_info$getOppositeComponent$dcea3e9ac80c85de;
extern _jc_method _jc_java_awt_event_FocusEvent$method_info$isTemporary$496c52edea5a99b7;
extern _jc_method _jc_java_awt_event_FocusEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_FocusEvent$vmethods {
	struct _jc_java_awt_Component$object	*(*getOppositeComponent$dcea3e9ac80c85de)(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*isTemporary$496c52edea5a99b7)(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_FocusEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_FocusEvent$vmethods	java_awt_event_FocusEvent;
};

// Vtype
struct _jc_java_awt_event_FocusEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_FocusEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_FocusEvent$sub_refs {
	struct _jc_java_awt_Component$object	*opposite;
};

// Reference instance fields (object)
struct _jc_java_awt_event_FocusEvent$refs {
    _jc_java_awt_event_FocusEvent$sub_refs	java_awt_event_FocusEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_FocusEvent$sub_nonrefs {
	jboolean	temporary;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_FocusEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_FocusEvent$sub_nonrefs	java_awt_event_FocusEvent;
};

// Object instance structure
struct _jc_java_awt_event_FocusEvent$object {
	_jc_java_awt_event_FocusEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_FocusEvent$vtype	*vtype;
	_jc_java_awt_event_FocusEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_FocusEvent$vtype _jc_java_awt_event_FocusEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_FocusEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_FocusEvent$class_object;

#endif	/* _JC_java_awt_event_FocusEvent_H_ */
